@@ -446,7 +446,7 @@ class SSHHook(BaseHook):
         :return: ``paramiko.PKey`` appropriate for given key
         :raises AirflowException: if key cannot be read
         """
-        if len(private_key.split("\n", 2)) < 2:
+        if len(private_key.splitlines()) < 2:
             raise AirflowException("Key must have BEGIN and END header/footer on separate lines.")
 
         for pkey_class in self._pkey_loaders:
@@ -512,7 +512,7 @@ class SSHHook(BaseHook):
         while not channel.closed or channel.recv_ready() or channel.recv_stderr_ready():
             readq, _, _ = select([channel], [], [], cmd_timeout)
             if cmd_timeout is not None:
-                timedout = len(readq) == 0
+                timedout = not readq
             for recv in readq:
                 if recv.recv_ready():
                     output = stdout.channel.recv(len(recv.in_buffer))
